@@ -43,20 +43,13 @@ public:
 
     virtual bool equals(RootObject *o);
 
-    /**
-     * Return <0, ==0, or >0 if this is less than, equal to, or greater than obj.
-     * Useful for sorting Objects.
-     */
-    virtual int compare(RootObject *obj);
-
     /**
      * Pretty-print an Object. Useful for debugging the old-fashioned way.
      */
     virtual const char *toChars();
     /// This function is `extern(D)` and should not be called from C++,
     /// as the ABI does not match on some platforms
-    virtual DArray<const char> toString();
-    virtual void toBuffer(OutBuffer *buf);
+    virtual DString toString();
 
     /**
      * Used as a replacement for dynamic_cast. Returns a unique number
