@@ -1,34 +1,20 @@
 
-/* Copyright (C) 1999-2018 by The D Language Foundation, All Rights Reserved
+/* Copyright (C) 1999-2019 by The D Language Foundation, All Rights Reserved
  * All Rights Reserved, written by Walter Bright
  * http://www.digitalmars.com
  * Distributed under the Boost Software License, Version 1.0.
- * (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)
- * https://github.com/dlang/dmd/blob/master/src/root/port.h
+ * http://www.boost.org/LICENSE_1_0.txt
+ * https://github.com/dlang/dmd/blob/master/src/dmd/root/port.h
  */
 
-#ifndef PORT_H
-#define PORT_H
+#pragma once
 
 // Portable wrapper around compiler/system specific things.
 // The idea is to minimize #ifdef's in the app code.
 
-#if IN_LLVM
-#include <cstdlib>
-#else
-#include <stdlib.h> // for alloca
-#endif
+#include <stddef.h>
 #include <stdint.h>
 
-#if _MSC_VER
-#include <alloca.h>
-typedef __int64 longlong;
-typedef unsigned __int64 ulonglong;
-#else
-typedef long long longlong;
-typedef unsigned long long ulonglong;
-#endif
-
 typedef unsigned char utf8_t;
 
 struct Port
@@ -40,12 +26,10 @@ struct Port
     static bool isFloat64LiteralOutOfRange(const char *s);
 
     static void writelongLE(unsigned value, void *buffer);
-    static unsigned readlongLE(void *buffer);
+    static unsigned readlongLE(const void *buffer);
     static void writelongBE(unsigned value, void *buffer);
-    static unsigned readlongBE(void *buffer);
-    static unsigned readwordLE(void *buffer);
-    static unsigned readwordBE(void *buffer);
+    static unsigned readlongBE(const void *buffer);
+    static unsigned readwordLE(const void *buffer);
+    static unsigned readwordBE(const void *buffer);
     static void valcpy(void *dst, uint64_t val, size_t size);
 };
-
-#endif
