@@ -42,10 +42,10 @@
 #include "gen/llvm.h"
 #include "gen/llvmhelpers.h"
 #include "gen/logger.h"
-#include "gen/metadata.h"
 #include "gen/modules.h"
 #include "gen/objcgen.h"
 #include "gen/optimizer.h"
+#include "gen/passes/metadata.h"
 #include "gen/passes/Passes.h"
 #include "gen/runtime.h"
 #include "gen/uda.h"
