@@ -26,14 +26,16 @@
 //===----------------------------------------------------------------------===//
 
 #include "gen/abi-x86-64.h"
-#include "aggregate.h"
-#include "declaration.h"
-#include "ldcbindings.h"
-#include "mtype.h"
-#include "target.h"
+
+#include "dmd/aggregate.h"
+#include "dmd/declaration.h"
+#include "dmd/identifier.h"
+#include "dmd/ldcbindings.h"
+#include "dmd/mtype.h"
+#include "dmd/target.h"
+#include "gen/abi.h"
 #include "gen/abi-generic.h"
 #include "gen/abi-x86-64.h"
-#include "gen/abi.h"
 #include "gen/dvalue.h"
 #include "gen/irstate.h"
 #include "gen/llvm.h"
@@ -47,7 +49,6 @@
 #include <utility>
 
 namespace {
-namespace dmd_abi {
 // Structs, static arrays and cfloats may be rewritten to exploit registers.
 // This function returns the rewritten type, or null if no transformation is
 // needed.
@@ -58,50 +59,51 @@ LLType *getAbiType(Type *ty) {
   }
 
   // Okay, we may need to transform. Figure out a canonical type:
+  llvm::SmallVector<Type *, 2> argTypes;
 
-  TypeTuple *argTypes = Target::toArgTypes(ty);
-  if (!argTypes || argTypes->arguments->empty()) {
-    return nullptr; // don't rewrite
+  // try to reuse cached arg{1,2}type of StructDeclarations
+  if (ty->ty == Tstruct) {
+    const auto sd = static_cast<TypeStruct *>(ty)->sym;
+    if (sd && sd->sizeok == SIZEOKdone) {
+      if (!sd->arg1type) {
+        return nullptr; // don't rewrite
+      }
+      argTypes.push_back(sd->arg1type);
+      if (sd->arg2type) {
+        argTypes.push_back(sd->arg2type);
+      }
+    }
+  }
+
+  if (argTypes.empty()) {
+    TypeTuple *tuple = target.toArgTypes(ty);
+    if (!tuple || tuple->arguments->empty()) {
+      return nullptr; // don't rewrite
+    }
+    for (auto param : *tuple->arguments) {
+      argTypes.push_back(param->type);
+    }
   }
 
   LLType *abiTy = nullptr;
-  if (argTypes->arguments->size() == 1) {
-    abiTy = DtoType((*argTypes->arguments->begin())->type);
-    // don't rewrite to a single bit (assertions in tollvm.cpp), choose a byte
-    // instead
-    abiTy = i1ToI8(abiTy);
+  if (argTypes.size() == 1) {
+    abiTy = DtoType(argTypes[0]);
   } else {
-    std::vector<LLType *> parts;
-    for (auto param : *argTypes->arguments) {
-      LLType *partType = DtoType(param->type);
-      // round up the DMD argtype for an eightbyte of a struct to a
-      // corresponding 64-bit type
-      // this makes sure that 64 bits of the chosen register are used and thus
-      // makes sure all potential padding bytes of a struct are copied
-      if (partType->isIntegerTy()) {
-        partType = LLType::getInt64Ty(gIR->context());
-      } else if (partType->isFloatTy()) {
-        partType = LLType::getDoubleTy(gIR->context());
-      }
-      parts.push_back(partType);
-    }
-    abiTy = LLStructType::get(gIR->context(), parts);
+    abiTy = LLStructType::get(gIR->context(),
+                              {DtoType(argTypes[0]), DtoType(argTypes[1])});
   }
 
   return abiTy;
 }
 
 bool passByVal(Type *ty) {
-  TypeTuple *argTypes = Target::toArgTypes(ty);
+  TypeTuple *argTypes = target.toArgTypes(ty);
   if (!argTypes) {
     return false;
   }
 
   return argTypes->arguments->empty(); // empty => cannot be passed in registers
 }
-} // namespace dmd_abi
-
-LLType *getAbiType(Type *ty) { return dmd_abi::getAbiType(ty->toBasetype()); }
 
 struct RegCount {
   char int_regs, sse_regs;
@@ -173,7 +175,7 @@ struct X86_64_C_struct_rewrite : ABIRewrite {
   LLValue *put(DValue *v, bool, bool) override {
     LLValue *address = getAddressOf(v);
 
-    LLType *abiTy = getAbiType(v->type);
+    LLType *abiTy = getAbiType(v->type->toBasetype());
     assert(abiTy && "Why are we rewriting a non-rewritten type?");
 
     return loadFromMemory(address, abiTy, ".X86_64_C_struct_rewrite_putResult");
@@ -183,7 +185,7 @@ struct X86_64_C_struct_rewrite : ABIRewrite {
     return DtoAllocaDump(v, dty, ".X86_64_C_struct_rewrite_dump");
   }
 
-  LLType *type(Type *t) override { return getAbiType(t); }
+  LLType *type(Type *t) override { return getAbiType(t->toBasetype()); }
 };
 
 /**
@@ -210,7 +212,9 @@ struct ImplicitByvalRewrite : ABIRewrite {
 
   void applyTo(IrFuncTyArg &arg, LLType *finalLType = nullptr) override {
     ABIRewrite::applyTo(arg, finalLType);
-    arg.attrs.addByVal(DtoAlignment(arg.type));
+    arg.attrs.addAttribute(LLAttribute::ByVal);
+    if (auto alignment = DtoAlignment(arg.type))
+      arg.attrs.addAlignmentAttr(alignment);
   }
 };
 
@@ -254,7 +258,7 @@ bool X86_64TargetABI::returnInArg(TypeFunction *tf, bool) {
   }
 
   Type *rt = tf->next->toBasetype();
-  return dmd_abi::passByVal(rt);
+  return ::passByVal(rt);
 }
 
 bool X86_64TargetABI::passByVal(TypeFunction *tf, Type *t) {
@@ -262,7 +266,7 @@ bool X86_64TargetABI::passByVal(TypeFunction *tf, Type *t) {
   if (tf->linkage == LINKcpp && !isPOD(t))
     return false;
 
-  return dmd_abi::passByVal(t->toBasetype());
+  return ::passByVal(t->toBasetype());
 }
 
 void X86_64TargetABI::rewriteArgument(IrFuncTy &fty, IrFuncTyArg &arg) {
