@@ -29,6 +29,9 @@
 #include "llvm/Support/CommandLine.h"
 #include "llvm/Target/TargetMachine.h"
 #include "llvm/Transforms/Instrumentation.h"
+#if LDC_LLVM_VER >= 900
+#include "llvm/Transforms/Instrumentation/AddressSanitizer.h"
+#endif
 #if LDC_LLVM_VER >= 800
 #include "llvm/Transforms/Instrumentation/MemorySanitizer.h"
 #include "llvm/Transforms/Instrumentation/ThreadSanitizer.h"
@@ -91,8 +94,10 @@ static cl::opt<cl::boolOrDefault, false, opts::FlagParser<cl::boolOrDefault>>
         "cross-module-inlining", cl::ZeroOrMore, cl::Hidden,
         cl::desc("(*) Enable cross-module function inlining (default disabled)"));
 
+#if LDC_LLVM_VER < 900
 static cl::opt<bool> unitAtATime("unit-at-a-time", cl::desc("Enable basic IPO"),
                                  cl::ZeroOrMore, cl::init(true));
+#endif
 
 static cl::opt<bool> stripDebug(
     "strip-debug", cl::ZeroOrMore,
@@ -187,7 +192,11 @@ static void addGarbageCollect2StackPass(const PassManagerBuilder &builder,
 static void addAddressSanitizerPasses(const PassManagerBuilder &Builder,
                                       PassManagerBase &PM) {
   PM.add(createAddressSanitizerFunctionPass());
+#if LDC_LLVM_VER >= 900
+  PM.add(createModuleAddressSanitizerLegacyPassPass());
+#else
   PM.add(createAddressSanitizerModulePass());
+#endif
 }
 
 static void addMemorySanitizerPass(const PassManagerBuilder &Builder,
@@ -290,7 +299,9 @@ static void addOptimizationPasses(legacy::PassManagerBase &mpm,
     builder.Inliner = createAlwaysInlinerPass();
 #endif
   }
+#if LDC_LLVM_VER < 900
   builder.DisableUnitAtATime = !unitAtATime;
+#endif
   builder.DisableUnrollLoops = optLevel == 0;
 
   builder.DisableUnrollLoops = (disableLoopUnrolling.getNumOccurrences() > 0)
@@ -453,7 +464,9 @@ void outputOptimizationSettings(llvm::raw_ostream &hash_os) {
   hash_os << disableSimplifyDruntimeCalls;
   hash_os << disableSimplifyLibCalls;
   hash_os << disableGCToStack;
+#if LDC_LLVM_VER < 900
   hash_os << unitAtATime;
+#endif
   hash_os << stripDebug;
   hash_os << disableLoopUnrolling;
   hash_os << disableLoopVectorization;
