@@ -18,7 +18,7 @@
 #endif
 
 #include "gen/attributes.h"
-#include "gen/metadata.h"
+#include "metadata.h"
 #include "gen/passes/Passes.h"
 #include "gen/runtime.h"
 #include "llvm/Pass.h"
@@ -79,11 +79,10 @@ void EmitMemSet(IRBuilder<> &B, Value *Dst, Value *Val, Value *Len,
                 const Analysis &A) {
   Dst = B.CreateBitCast(Dst, PointerType::getUnqual(B.getInt8Ty()));
 
-  CallSite CS =
-      B.CreateMemSet(Dst, Val, Len, 1 /*Align*/, false /*isVolatile*/);
+  auto CS = B.CreateMemSet(Dst, Val, Len, 1 /*Align*/, false /*isVolatile*/);
   if (A.CGNode) {
-    A.CGNode->addCalledFunction(
-        CS, A.CG->getOrInsertFunction(CS.getCalledFunction()));
+    auto calledFunc = CS->getCalledFunction();
+    A.CGNode->addCalledFunction(CS, A.CG->getOrInsertFunction(calledFunc));
   }
 }
 
@@ -452,7 +451,11 @@ static void RemoveCall(CallSite CS, const Analysis &A) {
 
   // Remove the runtime call.
   if (A.CGNode) {
+#if LDC_LLVM_VER >= 900
+    A.CGNode->removeCallEdgeFor(*cast<CallBase>(CS.getInstruction()));
+#else
     A.CGNode->removeCallEdgeFor(CS);
+#endif
   }
   CS->eraseFromParent();
 }
@@ -849,7 +852,7 @@ bool isSafeToStackAllocate(BasicBlock::iterator Alloc, Value *V,
           const unsigned paramHasAttr_firstArg = 0;
 #endif
           if (!CS.paramHasAttr(A - B + paramHasAttr_firstArg,
-                               LLAttribute::NoCapture)) {
+                               llvm::Attribute::AttrKind::NoCapture)) {
             // The parameter is not marked 'nocapture' - captured.
             return false;
           }
